"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.cloud_account_parameters import CloudAccountParameters
from delphix.api.gateway.model.create_cloud_account_parameters_all_of import CreateCloudAccountParametersAllOf
from delphix.api.gateway.model.tag import Tag
globals()['CloudAccountParameters'] = CloudAccountParameters
globals()['CreateCloudAccountParametersAllOf'] = CreateCloudAccountParametersAllOf
globals()['Tag'] = Tag
from delphix.api.gateway.model.create_cloud_account_parameters import CreateCloudAccountParameters


class TestCreateCloudAccountParameters(unittest.TestCase):
    """CreateCloudAccountParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCloudAccountParameters(self):
        """Test CreateCloudAccountParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCloudAccountParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.engine_storage_capacity_data import EngineStorageCapacityData
from delphix.api.gateway.model.engine_storage_capacity_dependency_data_all_of import EngineStorageCapacityDependencyDataAllOf
from delphix.api.gateway.model.engine_storage_dataset_type import EngineStorageDatasetType
from delphix.api.gateway.model.tag import Tag
globals()['EngineStorageCapacityData'] = EngineStorageCapacityData
globals()['EngineStorageCapacityDependencyDataAllOf'] = EngineStorageCapacityDependencyDataAllOf
globals()['EngineStorageDatasetType'] = EngineStorageDatasetType
globals()['Tag'] = Tag
from delphix.api.gateway.model.engine_storage_capacity_dependency_data import EngineStorageCapacityDependencyData


class TestEngineStorageCapacityDependencyData(unittest.TestCase):
    """EngineStorageCapacityDependencyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEngineStorageCapacityDependencyData(self):
        """Test EngineStorageCapacityDependencyData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EngineStorageCapacityDependencyData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.attach_cdbd_source_response import AttachCDBDSourceResponse
from delphix.api.gateway.model.cdb_d_source import CdbDSource
from delphix.api.gateway.model.delete_cdbd_source_response import DeleteCDBDSourceResponse
from delphix.api.gateway.model.delete_cdb_parameters import DeleteCDBParameters
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.detach_cdbd_source_response import DetachCDBDSourceResponse
from delphix.api.gateway.model.disable_cdbd_source_response import DisableCDBDSourceResponse
from delphix.api.gateway.model.disable_cdb_parameters import DisableCDBParameters
from delphix.api.gateway.model.enable_cdbd_source_response import EnableCDBDSourceResponse
from delphix.api.gateway.model.enable_cdb_parameters import EnableCDBParameters
from delphix.api.gateway.model.list_cdbd_sources_response import ListCDBDSourcesResponse
from delphix.api.gateway.model.oracle_attach_d_source_parameters import OracleAttachDSourceParameters
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_cdbd_sources_response import SearchCDBDSourcesResponse
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.update_cdb_d_source_parameters import UpdateCdbDSourceParameters
from delphix.api.gateway.model.update_cdb_d_source_response import UpdateCdbDSourceResponse
from delphix.api.gateway.model.upgrade_cdbd_source_response import UpgradeCDBDSourceResponse
from delphix.api.gateway.model.upgrade_oracle_container_database_parameters import UpgradeOracleContainerDatabaseParameters


class CDBDSourcesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __attach_cdb_dsource(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Attaches an Oracle CDB to an Oracle database.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.attach_cdb_dsource(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                oracle_attach_d_source_parameters (OracleAttachDSourceParameters): The parameters to attach a CDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                AttachCDBDSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.attach_cdb_dsource = _Endpoint(
            settings={
                'response_type': (AttachCDBDSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}/attach-cdb',
                'operation_id': 'attach_cdb_dsource',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                    'oracle_attach_d_source_parameters',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                    'oracle_attach_d_source_parameters':
                        (OracleAttachDSourceParameters,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                    'oracle_attach_d_source_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__attach_cdb_dsource
        )

        def __create_cdb_dsource_tags(
            self,
            cdb_d_source_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a CDB DSource.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_cdb_dsource_tags(cdb_d_source_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.
                tags_request (TagsRequest): Tags information for CDB DSource.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_cdb_dsource_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}/tags',
                'operation_id': 'create_cdb_dsource_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                    'tags_request',
                ],
                'required': [
                    'cdb_d_source_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_cdb_dsource_tags
        )

        def __delete_cdb_dsource(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Delete a CDB dSource.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_cdb_dsource(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                delete_cdb_parameters (DeleteCDBParameters): The parameters to delete a CDB dSource.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DeleteCDBDSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.delete_cdb_dsource = _Endpoint(
            settings={
                'response_type': (DeleteCDBDSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}/delete',
                'operation_id': 'delete_cdb_dsource',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                    'delete_cdb_parameters',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                    'delete_cdb_parameters':
                        (DeleteCDBParameters,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                    'delete_cdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_cdb_dsource
        )

        def __delete_cdb_dsource_tags(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Delete tags for a CDB DSource.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_cdb_dsource_tags(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.delete_cdb_dsource_tags = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}/tags/delete',
                'operation_id': 'delete_cdb_dsource_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                    'delete_tag',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_cdb_dsource_tags
        )

        def __detach_cdb_dsource(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Detaches an Oracle CDB from an Oracle database.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.detach_cdb_dsource(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DetachCDBDSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.detach_cdb_dsource = _Endpoint(
            settings={
                'response_type': (DetachCDBDSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}/detach-cdb',
                'operation_id': 'detach_cdb_dsource',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__detach_cdb_dsource
        )

        def __disable_cdb_dsource(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Disable a CDB dSource.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.disable_cdb_dsource(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                disable_cdb_parameters (DisableCDBParameters): The parameters to disable a CDB dSource.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DisableCDBDSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.disable_cdb_dsource = _Endpoint(
            settings={
                'response_type': (DisableCDBDSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}/disable',
                'operation_id': 'disable_cdb_dsource',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                    'disable_cdb_parameters',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                    'disable_cdb_parameters':
                        (DisableCDBParameters,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                    'disable_cdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__disable_cdb_dsource
        )

        def __enable_cdb_dsource(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Enable a CDB dSource.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.enable_cdb_dsource(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                enable_cdb_parameters (EnableCDBParameters): The parameters to enable a CDB dSource.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EnableCDBDSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.enable_cdb_dsource = _Endpoint(
            settings={
                'response_type': (EnableCDBDSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}/enable',
                'operation_id': 'enable_cdb_dsource',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                    'enable_cdb_parameters',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                    'enable_cdb_parameters':
                        (EnableCDBParameters,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                    'enable_cdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__enable_cdb_dsource
        )

        def __get_cdb_dsource_by_id(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Get a CDB dSource by ID (Oracle only).  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_cdb_dsource_by_id(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CdbDSource
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.get_cdb_dsource_by_id = _Endpoint(
            settings={
                'response_type': (CdbDSource,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}',
                'operation_id': 'get_cdb_dsource_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_cdb_dsource_by_id
        )

        def __get_cdb_dsources(
            self,
            **kwargs
        ):
            """List all CDB dSources (Oracle only).  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_cdb_dsources(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListCDBDSourcesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_cdb_dsources = _Endpoint(
            settings={
                'response_type': (ListCDBDSourcesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources',
                'operation_id': 'get_cdb_dsources',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "ENABLED": "enabled",
                        "-ENABLED": "-enabled",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "DESCRIPTION": "description",
                        "-DESCRIPTION": "-description",
                        "CDB_SOURCE_ID": "cdb_source_id",
                        "-CDB_SOURCE_ID": "-cdb_source_id",
                        "IS_DETACHED": "is_detached",
                        "-IS_DETACHED": "-is_detached",
                        "LOGSYNC_ENABLED": "logsync_enabled",
                        "-LOGSYNC_ENABLED": "-logsync_enabled",
                        "LOGSYNC_MODE": "logsync_mode",
                        "-LOGSYNC_MODE": "-logsync_mode",
                        "LOGSYNC_INTERVAL": "logsync_interval",
                        "-LOGSYNC_INTERVAL": "-logsync_interval",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "NAMESPACE_ID": "namespace_id",
                        "-NAMESPACE_ID": "-namespace_id",
                        "NAMESPACE_NAME": "namespace_name",
                        "-NAMESPACE_NAME": "-namespace_name",
                        "IS_REPLICA": "is_replica",
                        "-IS_REPLICA": "-is_replica",
                        "GROUP_NAME": "group_name",
                        "-GROUP_NAME": "-group_name",
                        "DIAGNOSE_NO_LOGGING_FAULTS": "diagnose_no_logging_faults",
                        "-DIAGNOSE_NO_LOGGING_FAULTS": "-diagnose_no_logging_faults",
                        "RMAN_CHANNELS": "rman_channels",
                        "-RMAN_CHANNELS": "-rman_channels",
                        "FILES_PER_SET": "files_per_set",
                        "-FILES_PER_SET": "-files_per_set",
                        "NUMBER_OF_CONNECTIONS": "number_of_connections",
                        "-NUMBER_OF_CONNECTIONS": "-number_of_connections",
                        "BANDWIDTH_LIMIT": "bandwidth_limit",
                        "-BANDWIDTH_LIMIT": "-bandwidth_limit",
                        "COMPRESSED_LINKING_ENABLED": "compressed_linking_enabled",
                        "-COMPRESSED_LINKING_ENABLED": "-compressed_linking_enabled",
                        "ENCRYPTED_LINKING_ENABLED": "encrypted_linking_enabled",
                        "-ENCRYPTED_LINKING_ENABLED": "-encrypted_linking_enabled",
                        "CHECK_LOGICAL": "check_logical",
                        "-CHECK_LOGICAL": "-check_logical",
                        "BACKUP_LEVEL_ENABLED": "backup_level_enabled",
                        "-BACKUP_LEVEL_ENABLED": "-backup_level_enabled"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_cdb_dsources
        )

        def __get_tags_cdb_dsource(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Get tags for a CDB DSource.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_tags_cdb_dsource(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.get_tags_cdb_dsource = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}/tags',
                'operation_id': 'get_tags_cdb_dsource',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_tags_cdb_dsource
        )

        def __search_cdb_dsources(
            self,
            **kwargs
        ):
            """Search for CDB dSources (Oracle only).  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_cdb_dsources(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchCDBDSourcesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_cdb_dsources = _Endpoint(
            settings={
                'response_type': (SearchCDBDSourcesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/search',
                'operation_id': 'search_cdb_dsources',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "ENABLED": "enabled",
                        "-ENABLED": "-enabled",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "DESCRIPTION": "description",
                        "-DESCRIPTION": "-description",
                        "CDB_SOURCE_ID": "cdb_source_id",
                        "-CDB_SOURCE_ID": "-cdb_source_id",
                        "IS_DETACHED": "is_detached",
                        "-IS_DETACHED": "-is_detached",
                        "LOGSYNC_ENABLED": "logsync_enabled",
                        "-LOGSYNC_ENABLED": "-logsync_enabled",
                        "LOGSYNC_MODE": "logsync_mode",
                        "-LOGSYNC_MODE": "-logsync_mode",
                        "LOGSYNC_INTERVAL": "logsync_interval",
                        "-LOGSYNC_INTERVAL": "-logsync_interval",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "NAMESPACE_ID": "namespace_id",
                        "-NAMESPACE_ID": "-namespace_id",
                        "NAMESPACE_NAME": "namespace_name",
                        "-NAMESPACE_NAME": "-namespace_name",
                        "IS_REPLICA": "is_replica",
                        "-IS_REPLICA": "-is_replica",
                        "GROUP_NAME": "group_name",
                        "-GROUP_NAME": "-group_name",
                        "DIAGNOSE_NO_LOGGING_FAULTS": "diagnose_no_logging_faults",
                        "-DIAGNOSE_NO_LOGGING_FAULTS": "-diagnose_no_logging_faults",
                        "RMAN_CHANNELS": "rman_channels",
                        "-RMAN_CHANNELS": "-rman_channels",
                        "FILES_PER_SET": "files_per_set",
                        "-FILES_PER_SET": "-files_per_set",
                        "NUMBER_OF_CONNECTIONS": "number_of_connections",
                        "-NUMBER_OF_CONNECTIONS": "-number_of_connections",
                        "BANDWIDTH_LIMIT": "bandwidth_limit",
                        "-BANDWIDTH_LIMIT": "-bandwidth_limit",
                        "COMPRESSED_LINKING_ENABLED": "compressed_linking_enabled",
                        "-COMPRESSED_LINKING_ENABLED": "-compressed_linking_enabled",
                        "ENCRYPTED_LINKING_ENABLED": "encrypted_linking_enabled",
                        "-ENCRYPTED_LINKING_ENABLED": "-encrypted_linking_enabled",
                        "CHECK_LOGICAL": "check_logical",
                        "-CHECK_LOGICAL": "-check_logical",
                        "BACKUP_LEVEL_ENABLED": "backup_level_enabled",
                        "-BACKUP_LEVEL_ENABLED": "-backup_level_enabled"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_cdb_dsources
        )

        def __update_cdb_dsource(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Update a CDB DSource.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_cdb_dsource(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                update_cdb_d_source_parameters (UpdateCdbDSourceParameters): The parameters to update a CDB DSource.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateCdbDSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.update_cdb_dsource = _Endpoint(
            settings={
                'response_type': (UpdateCdbDSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}',
                'operation_id': 'update_cdb_dsource',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                    'update_cdb_d_source_parameters',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                    'update_cdb_d_source_parameters':
                        (UpdateCdbDSourceParameters,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                    'update_cdb_d_source_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_cdb_dsource
        )

        def __upgrade_cdb_dsource(
            self,
            cdb_d_source_id,
            **kwargs
        ):
            """Upgrade Oracle CDB dSource  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.upgrade_cdb_dsource(cdb_d_source_id, async_req=True)
            >>> result = thread.get()

            Args:
                cdb_d_source_id (str): The ID of the CDB DSource.

            Keyword Args:
                upgrade_oracle_container_database_parameters (UpgradeOracleContainerDatabaseParameters): The new data to upgrade an Oracle CDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpgradeCDBDSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['cdb_d_source_id'] = \
                cdb_d_source_id
            return self.call_with_http_info(**kwargs)

        self.upgrade_cdb_dsource = _Endpoint(
            settings={
                'response_type': (UpgradeCDBDSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/cdb-dsources/{cdbDSourceId}/upgrade',
                'operation_id': 'upgrade_cdb_dsource',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cdb_d_source_id',
                    'upgrade_oracle_container_database_parameters',
                ],
                'required': [
                    'cdb_d_source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'cdb_d_source_id',
                ]
            },
            root_map={
                'validations': {
                    ('cdb_d_source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cdb_d_source_id':
                        (str,),
                    'upgrade_oracle_container_database_parameters':
                        (UpgradeOracleContainerDatabaseParameters,),
                },
                'attribute_map': {
                    'cdb_d_source_id': 'cdbDSourceId',
                },
                'location_map': {
                    'cdb_d_source_id': 'path',
                    'upgrade_oracle_container_database_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__upgrade_cdb_dsource
        )
